# Main class for influxdb
#
# Most settings here relate to the config file, influxdb.conf.erb

class influxdb (
  Boolean $manage_repo,
  Boolean $manage_ssl_certs,
  String $repo_url,
  String $repo_keyurl,
  String $repo_keyid,
  Enum['stopped', 'running'] $service_ensure,
  String $admin_password,
  Boolean $backup_enabled,
  String $backup_directory,
  Integer[0,23] $daily_backup_hour,
  Integer[0,59] $daily_backup_minute,
  Integer[0,23] $daily_tidy_hour,
  Integer[0,59] $daily_tidy_minute,
  Integer $backup_keep,
  Boolean $api_unsafe_ssl,
  Boolean $reporting_disabled,
  Influxdb::Bindaddr $bind_address,
  String $meta_dir,
  Boolean $meta_retention_autocreate,
  Boolean $meta_logging_enabled,
  String $data_dir,
  String $data_wal_dir,
  Influxdb::Time $data_wal_fsync_delay,
  Enum['inmem', 'tsi1'] $data_index_version,
  Boolean $data_trace_logging_enabled,
  Boolean $data_query_log_enabled,
  Boolean $data_validate_keys,
  Influxdb::Bytesize $data_cache_max_memory_size,
  Influxdb::Bytesize $data_cache_snapshot_memory_size,
  Influxdb::Time $data_cache_snapshot_write_cold_duration,
  Influxdb::Time $data_compact_full_write_cold_duration,
  Integer $data_max_concurrent_compactions,
  Influxdb::Bytesize $data_compact_throughput,
  Influxdb::Bytesize $data_compact_throughput_burst,
  Boolean $data_tsm_use_madv_willneed,
  Integer $data_max_series_per_database,
  Integer $data_max_values_per_tag,
  Influxdb::Bytesize $data_max_index_log_file_size,
  Integer $data_series_id_set_cache_size,
  Influxdb::Time $coordinator_write_timeout,
  Integer $coordinator_max_concurrent_queries,
  Influxdb::Time $coordinator_query_timeout,
  Influxdb::Time $coordinator_log_queries_after,
  Integer $coordinator_max_select_point,
  Integer $coordinator_max_select_series,
  Integer $coordinator_max_select_buckets,
  Boolean $retention_enabled,
  Influxdb::Time $retention_check_interval,
  Boolean $shard_precreation_enabled,
  Influxdb::Time $shard_precreation_check_interval,
  Influxdb::Time $shard_precreation_advance_period,
  Boolean $monitor_store_enabled,
  String $monitor_store_database,
  Influxdb::Time $monitor_store_interval,
  Boolean $http_enabled,
  Boolean $http_flux_enabled,
  Boolean $http_flux_log_enabled,
  Influxdb::Bindaddr $http_bind_address,
  Boolean $http_auth_enabled,
  String $http_realm,
  Boolean $http_log_enabled,
  Boolean $http_suppress_write_log,
  String $http_access_log_path,
  String $http_access_log_status_filters,
  Boolean $http_write_tracing,
  Boolean $http_pprof_enabled,
  Boolean $http_debug_pprof_enabled,
  Boolean $http_https_enabled,
  String $http_https_certificate_path,
  String $http_https_certificate_content,
  String $http_https_private_key_path,
  String $http_https_private_key_content,
  String $http_https_private_key_group,
  String $http_shared_secret,
  Integer $http_max_row_limit,
  Integer $http_max_connection_limit,
  Boolean $http_unix_socket_enabled,
  String $http_bind_socket,
  Integer $http_max_body_size,
  Integer $http_max_concurrent_write_limit,
  Integer $http_max_enqueued_write_limit,
  Integer $http_enqueued_write_timeout,
  Enum['auto', 'logfmt', 'json'] $logging_format,
  Enum['error', 'warn', 'info', 'debug'] $logging_level,
  Boolean $logging_suppress_logo,
  Boolean $subscriber_enabled,
  Influxdb::Time $subscriber_http_timeout,
  Boolean $subscriber_insecure_skip_verify,
  String $subscriber_ca_certs,
  Integer $subscriber_write_concurrency,
  Integer $subscriber_write_buffer_size,
  Boolean $continuous_queries_enabled,
  Boolean $continuous_queries_log_enabled,
  Boolean $continuous_queries_query_stats_enabled,
  Influxdb::Time $continuous_queries_run_interval,
  String $tls_ciphers,
  String $tls_min_version,
  String $tls_max_version,
  Boolean $collectd_enabled,
  Influxdb::Bindaddr $collectd_bind_address,
  String $collectd_database,
  String $collectd_retention_policy,
  Integer $collectd_batch_size,
  Integer $collectd_batch_pending,
  Influxdb::Time $collectd_batch_timeout,
  Integer $collectd_read_buffer,
  String $collectd_typesdb,
  String $collectd_security_level,
  String $collectd_auth_file,
  String $collectd_parse_multivalue_plugin,
) {

  contain ::influxdb::install
  contain ::influxdb::config

  Class['::influxdb::install']
  -> Class['::influxdb::config']

  if $http_https_enabled {
    if $api_unsafe_ssl {
      $influx_cmd = 'influx -ssl -unsafeSsl'
    } else {
      $influx_cmd = 'influx -ssl'
    }
  } else {
    $influx_cmd = 'influx'
  }
}
